@@ -27,13 +27,14 @@ Log::WarnDie - Log standard Perl warnings and errors on a log handler
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
     use Log::WarnDie; # install to be used later
+    use Log::Dispatch;
 
-    my $dispatcher = Log::Dispatch->new;       # can be any dispatcher!
+    my $dispatcher = Log::Dispatch->new();       # can be any dispatcher!
     $dispatcher->add( Log::Dispatch::Foo->new( # whatever output you like
      name      => 'foo',
      min_level => 'info',
@@ -73,7 +74,7 @@ enabled at any time for critical sections of code.
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SUBROUTINES/METHODS
 
@@ -240,7 +241,14 @@ BEGIN {
 		    $DISPATCHER->critical( @_ );
 	   }
         }
-        $DIE ? $DIE->( @_ ) : CORE::die( @_ );
+	# Handle http://stackoverflow.com/questions/8078220/custom-error-handling-is-catching-errors-that-normally-are-not-displayed
+	# $DIE ? $DIE->( @_ ) : CORE::die( @_ );
+	if($DIE) {
+		$DIE->(@_);
+	} else {
+		return unless((defined $^S) && ($^S == 0));	# Ignore errors in eval
+		CORE::die(@_);
+	}
     };
 
 #  Make sure we won't be listed ourselves by Carp::
@@ -262,9 +270,9 @@ BEGIN {
 
 Class method to set and/or return the current dispatcher
 
- IN: 1 class (ignored)
-     2 new dispatcher (optional)
- OUT: 1 current dispatcher
+# IN: 1 class (ignored)
+#     2 new dispatcher (optional)
+# OUT: 1 current dispatcher
 
 =cut
 
@@ -359,7 +367,7 @@ installed.  Please note that for testing this module, you will need the
 L<Log::Dispatch::Buffer> module to also be available.
 
 This module has been tested with
-L<Log::Dispatch>, L<Log::Any> and L<Log::Log4perl> B<without>.
+L<Log::Dispatch>, L<Log::Any> and L<Log::Log4perl>.
 In principle any object which recognises C<warning>, C<error> and C<critical> should work.
 
 =head2 eval
@@ -370,7 +378,7 @@ handler _will_ get called inside the eval.  Which may or may not be what you
 want.  To prevent the __DIE__ handler to be called inside eval's, add the
 following line to the eval block or string being evaluated:
 
-  local $SIG{__DIE__} = undef;
+    local $SIG{__DIE__} = undef;
 
 This disables the __DIE__ handler within the evalled block or string, and
 will automatically enable it again upon exit of the evalled block or string.
